@@ -43,5 +43,5 @@ class User():
         name, email, password- information to add
         '''
         data = {"name":name, "email":email, 'password': password}
-        res = db_service.post('/auth/register', data)
+        res = db_service.post('/users', data)
         return res
