@@ -61,8 +61,6 @@ class Utils():
 
     @classmethod
     def concatenate_output(cls, lst_1, lst_2):
-        if not lst_1 and not lst_2:
-            return []
         if type(lst_1) != type(lst_2):
             print('ERROR in concatenate_output(): Not the same type')
             return []
@@ -70,6 +68,8 @@ class Utils():
             return lst_1 + lst_2
         if isinstance(lst_1, pd.DataFrame):
             return pd.concat([lst_1, lst_2], ignore_index=True)
+        if not lst_1 and not lst_2:
+            return []
 
     @classmethod
     def build_filter_params_v0(cls, filter_, pre_character='&'):
@@ -225,20 +225,20 @@ class Utils():
             return False
 
     @classmethod
-    def check_function(cls, submission, solution, test_cases=None):
+    def check_function(cls, submission, solution, global_dict, test_cases=None):
         if not test_cases:
             cls.printt("No test cases input")
             return 'INVALID'
 
         try:
             score = 0
-            exec(submission)
-            exec(solution)
+            exec(submission, global_dict)
+            exec(solution, global_dict)
             func_name_sub = submission.split('(')[0][4:]
             func_name_sol = solution.split('(')[0][4:]
             for tc in test_cases:
-                result_sub = locals()[func_name_sub](*tc)
-                result_sol = locals()[func_name_sol](*tc)
+                result_sub = global_dict[func_name_sub](*tc)
+                result_sol = global_dict[func_name_sol](*tc)
                 if cls.is_equal(result_sub,result_sol):
                     score += 1
             cls.printt(f'You have passed {score}/{len(test_cases)} test cases')
